#!/bin/nawk -f
###run_list.sb2000_bias - lists roll & pitch biases in a SB2000 (raw log) file.
###                       Also flags if depth correction code i.e. how depths
###			  are logged does not = 1 ("apparent" or uncorrected depth)
###			  which is the SIO standard convention
#
## smsmith 6nov00 gdcultra
#
# input file is a SB2000 sb2000.[date] bathymetry file. e.g. sb2000.98sep29

# the output from this nawk program can be fed to another script that lists changes
# to the roll or pitch values.

{if (NR == 1) 
 { print "### File:", FILENAME
   print "## yyyy ddd  hh mm ss.s  roll  pitch biases"
 }
}

/SP/ {
 # location of "SP" flag in record:
 nsp = index($0,"SP")
 # NF = number (not contents) of last field:
 # nlast = number (not contents) of next-to-last field:
 nlast = NF - 1
 sps = substr($0,nsp,2)
 yr  = substr($0,nsp+2,4)
 jdy = substr($0,nsp+6,3)
 hr  = substr($0,nsp+9,2)  * 1.0
 min = substr($0,nsp+11,2) * 1.0
 sec = substr($0,nsp+13,3) * 0.1
 rollbias = $NF * 0.01
 pitchbias = $nlast * 0.01
 #printf("%s %04d %03d  %02d %02d %04.1f  %05.2f %05.2f\n", sps, yr, jdy, hr, min, sec, $nlast * .01, $NF * .01)
 printf("%s %04d %03d  %02d %02d %04.1f  %05.2f %05.2f\n", sps, yr, jdy, hr, min, sec, rollbias, pitchbias)
 }


/SR/ {
 nsp = index($0,"SR")
 depcor = substr($0,nsp+19,1)
 if (depcor != 1)
   {
   sps = substr($0,nsp,2)
   yr  = substr($0,nsp+2,4)
   jdy = substr($0,nsp+6,3)
   hr  = substr($0,nsp+9,2)  * 1.0
   min = substr($0,nsp+11,2) * 1.0
   sec = substr($0,nsp+13,3) * 0.1
#   print "SR ERROR Depth correction code = ", depcor, "Should = 1 (apparent, uncorrected depth)"  
printf("%s %04d %03d  %02d %02d %04.1f  ERROR - Depths NOT in uncorrected meters. Code = %2d, should = 1\n", sps, yr, jdy, hr, min, sec, depcor)
   }
  }

