###DOmake.ssv_2.page.plots - creates 24hr profile ps plot file of INS data
##
## smsmith Mar96 mlvl62 - based on DOmake.imet.page.plot
#
# Assumes environmental variables CRUISE, DIRUWDATA and BINDIR are set.

unset noclobber

if ($#argv < 1) then
   echo "usage: DOmake.ssv_2.page.plot   <date.ext>"
   echo " (produces profile ps file named ctfile.<date.ext>.ps)"
   exit
endif

# Change these Lower/Upper ranges as necessary:

set SAL_RANGE     = 30/37
set SAL_TIC     = "a1g1f1:Salinity (psu):"

set H2OTEMP_RANGE = 15/40
set H2OTEMP_TIC = "a2g2f1:h2o temp (C.):"

set COND_RANGE     = 45/60
set COND_TIC     = "a2g2f1:Conductivity (mmho):"

set SSV_RANGE     = 1480/1540
set SSV_TIC     = "a2g2f1:Surface SV (mps):"

# Don't change these:
set HR_RANGE       = 0./24.       ; set HR_TIC       = "2g1::"

set PRINTr = $LPDEST

cd $DIRUWDATA/MET

set DATE = $1

set IFN = `$BINDIR/ins_filename $DATE`

# test for a compressed file if exists then uncompress it
if ( -e $IFN.Z) then
	uncompress $IFN
endif

# test for the data file to exist
if !( -e $IFN) then
	echo "DOmake.ssv_2.page.plot: No data file: $IFN"
	exit
endif

###################################################

set PAGE_SIZE = letter

set OFN = SSV_2.$IFN.ps

if ("$PAGE_SIZE" == "letter") then
   set XLENGTH = 6.5
   set YLENGTH = 1.8
   set XOFF1 = 1.2 ; set YOFF1 =  8.0
   set XOFF2 = 0.0 ; set YOFF2 = -2.3
   set OPT    = " -P "
else if ("$PAGE_SIZE" == "E") then
   echo E-size not done yet...
   exit
else 
   echo Should not be here with PAGE_SIZE of $PAGE_SIZE...
   exit
endif

set TITLE1   = "SSV data (sensor 2) $CRUISE  $DATE"
set TITLE2   = ""

set SIZE     = "$XLENGTH"/"$YLENGTH"
set SIZE_REV = "$XLENGTH"/-"$YLENGTH"
set AXES     = WeSn

/usr/local/bin/ins/ins_tcsv < $IFN > all_data

###################### start the postscript file ############################
pwd | psxy -H1 >! $OFN -R0/1/0/1 -JX1/1 -X0 -Y0 -K `echo "$OPT"`


###################### start 1st panel ######################################
#
# First temp sensor

$BINDIR/ct_ins_data.awk field=6 scale=1 all_data > 2col

set XOFF   = $XOFF1
set YOFF   = $YOFF1
set TITLE  = "$TITLE1"
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$H2OTEMP_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
set SYMB   = x0.05

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################

###################### start 2nd panel ######################################

$BINDIR/ct_ins_data.awk field=7 scale=1 all_data > 2col
set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$COND_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
#
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################

###################### start 3nd panel ######################################

$BINDIR/ct_ins_data.awk field=8 scale=1 all_data > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$SAL_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#
###################### start 4st panel ######################################

$BINDIR/ct_ins_data.awk field=9 scale=4 all_data > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = "$TITLE"
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$SSV_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
set SYMB   = x0.05

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0


psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################

#

### finish off the postscript file ##########################################
pwd | psxy -H1 >> $OFN -R -JX -O `echo "$OPT"`
#
# Print the file
#
lp $OFN

#compress files:
compress $IFN
#end
